@@ -1,10 +1,14 @@
 package Language::Expr::Interpreter::Dummy;
 BEGIN {
-  $Language::Expr::Interpreter::Dummy::VERSION = '0.17';
+  $Language::Expr::Interpreter::Dummy::VERSION = '0.18';
 }
 # ABSTRACT: Dummy interpreter for Language::Expr (used for testing)
 
-use Any::Moose;
+use 5.010;
+use strict;
+use warnings;
+
+use Moo;
 with 'Language::Expr::EvaluatorRole';
 extends 'Language::Expr::Evaluator';
 
@@ -41,8 +45,6 @@ sub rule_parenthesis { }
 sub expr_preprocess { }
 sub expr_postprocess { }
 
-__PACKAGE__->meta->make_immutable;
-no Any::Moose;
 1;
 
 __END__
@@ -54,7 +56,7 @@ Language::Expr::Interpreter::Dummy - Dummy interpreter for Language::Expr (used
 
 =head1 VERSION
 
-version 0.17
+version 0.18
 
 =head1 DESCRIPTION
 
